pub struct EditorConfigSnapshot {
pub settings_file: Option<String>,
pub has_settings_handler: bool,
pub custom_zoom_levels: Vec<f32>,
pub canvas_size_mode: CanvasSizeMode,
pub drag_button: MouseButton,
pub select_button: MouseButton,
pub navigate_button: MouseButton,
pub context_menu_button: MouseButton,
pub enable_smooth_zoom: bool,
pub smooth_zoom_power: f32,
}Expand description
Immutable view of the configuration used to create an editor context.
Callback function pointers and native storage pointers are intentionally not exposed. The snapshot only reports whether a settings handler was installed.
Fields
settings_file: Option<String>has_settings_handler: boolcustom_zoom_levels: Vec<f32>canvas_size_mode: CanvasSizeModeenable_smooth_zoom: boolsmooth_zoom_power: f32Trait Implementations
Sourceimpl Clone for EditorConfigSnapshot
impl Clone for EditorConfigSnapshot
Sourcefn clone(&self) -> EditorConfigSnapshot
fn clone(&self) -> EditorConfigSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EditorConfigSnapshot
impl Debug for EditorConfigSnapshot
Sourceimpl PartialEq for EditorConfigSnapshot
impl PartialEq for EditorConfigSnapshot
Sourcefn eq(&self, other: &EditorConfigSnapshot) -> bool
fn eq(&self, other: &EditorConfigSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for EditorConfigSnapshot